<?php

/**
 * Customizer Control: buttonset.
 *
 * @since   1.0.0
 *
 * @package Newslist WordPress theme
 */

# Exit if accessed directly.
if (!defined('ABSPATH')) {
	exit;
}

if (class_exists('WP_Customize_Control')) {
	class Newslist_Customizer_Buttonset_Control extends WP_Customize_Control
	{

		/**
		 * The control type.
		 *
		 * @since  1.0.0
		 * @access public
		 * @var string
		 *
		 * @package Newslist WordPress Theme
		 */
		public $type = 'buttonset';

		/**
		 * Refresh the parameters passed to the JavaScript via JSON.
		 *
		 * @see WP_Customize_Control::to_json()
		 *
		 * @access public
		 * @since 1.0.0
		 *
		 * @package Newslist WordPress Theme
		 */
		public function to_json()
		{
			parent::to_json();

			if (isset($this->default)) {
				$this->json['default'] = $this->default;
			} else {
				$this->json['default'] = $this->setting->default;
			}
			$this->json['value']       = $this->value();
			$this->json['choices']     = $this->choices;
			$this->json['link']        = $this->get_link();
			$this->json['id']          = $this->id;

			$this->json['inputAttrs'] = '';
			foreach ($this->input_attrs as $attr => $value) {
				$this->json['inputAttrs'] .= $attr . '="' . esc_attr($value) . '" ';
			}
		}

		/**
		 * An Underscore (JS) template for this control's content (but not its container).
		 *
		 * Class variables for this control class are available in the `data` JS object;
		 * export custom variables by overriding {@see WP_Customize_Control::to_json()}.
		 *
		 * @see WP_Customize_Control::print_template()
		 *
		 * @access protected
		 * @since 1.0.0
		 *
		 * @package Newslist WordPress Theme
		 */
		protected function content_template()
		{
?>
			<# if ( data.label ) { #>
				<span class="customize-control-title">{{{ data.label }}}</span>
				<# } #>
					<# if ( data.description ) { #>
						<span class="description customize-control-description">{{{ data.description }}}</span>
						<# } #>
							<div id="input_{{ data.id }}" class="buttonset">
								<# for ( key in data.choices ) { #>
									<input {{{ data.inputAttrs }}} class="switch-input" type="radio" value="{{ key }}" name="_customize-radio-{{{ data.id }}}" id="{{ data.id }}{{ key }}" {{{ data.link }}}<# if ( key===data.value ) { #> checked="checked" <# } #>>
										<label class="switch-label switch-label-<# if ( key === data.value ) { #>on <# } else { #>off<# } #>" for="{{ data.id }}{{ key }}">
											{{ data.choices[ key ] }}
										</label>
										</input>
										<# } #>
							</div>
				<?php
			}
		}
	}

	Newslist_Customizer::add_custom_control(array(
		'type'     => 'buttonset',
		'class'    => 'Newslist_Customizer_Buttonset_Control',
		'sanitize' =>  array('Newslist_Customizer', 'sanitize_choice')
	));
